====================================
Community DigitalOcean Release Notes
====================================

.. contents:: Topics


v0.1.0
======

Release Summary
---------------

Initial release of the collection after extracing the modules from `community.general <https://github.com/ansible-collections/community.general/>`_.
